# -*- coding:utf-8 -*-

commonInfoStr = {}

commonInfoStr['en'] = {
    # /*Login Strings*/
    'STR_LOGINWELCOME': "Please type your user name and password",
    'STR_LOGINFAILED': "Login failed. Please try again",
    'STR_LOGIN_ERROR': "Invalid Authentication",
    'STR_LOGIN_NOACCESS': "No Privilege user",
    'STR_LOGIN_BWSRNOTSPRT': "NOT SUPPORTED BROWSER",
    'STR_LOGIN_BWSRMSG': "This software does not support this browser version.Please check User\'s Guide for supported browsers.",

    'STR_LOGIN_SESSION_EXPIRED': "Session expired, please relogin!",
    'STR_LOGIN': "Authentication Required",
    'STR_LOGIN_ERROR_3': "Maximum number of sessions already in use",
    'STR_USER_REQUIRED': "Username is required",
    'STR_PWD_REQUIRED': "Password is required",
    'STR_COOKIES_ENABLE': "Please enable the cookies in order to log into the system",
    'STR_FIRST_COOKIES_BLOCK': "Cookies are enabled, First party cookies are still blocked",
    'STR_USER_ROLE_ERROR': "Couldn\'t get role for the user",
    'STR_LAN_CHANNEL_ERROR': "Couldn\'t retrieve lan channel information",
    'STR_PROJECT_CFG_ERROR': "Couldn\'t retrieve project configuration",
    'STR_USER_LENGTH': "Username length cannot exceed more than 800 characters",
    'STR_PWD_LENGTH': "Password length cannot exceed more than 300 characters",
    'UID': "UID State",
    'activeSession': "Active Session",
    'diagnosis': "Diagnostics",
    'userManage': "User Administration",
    'sysadmin': "System Administrator",
    'localUser': "Local Users",
    'DirGroup': "Directory Group",
    'shk': "SSH Key",
    'sslC': "SSL Certificate",
    'ldapSet': "LDAP Settings",
    'adSet': "AD Settings",
    'sso': "SSO",
    'loginSB': "Login Security Banner",
    'security': "Security",
    'openFile': "open file...",
    'illegalInput': "Unreasonable input,please enter a number starting from 1 ",
    'videoTitle': "Video Log",

    # alert
    'alertTitle': "Alert Settings",
    'alertNote': "Manage Alert Settings.",
    'tagSnmpName': "SNMP Alert",
    'tagEmailName': "Email Alert",
    'strSnmpSuppot': "SNMP Alert Support",
    'strSnmpDestAddr': "Destination Address",
    'strSnmpAlertLev': "SNMP Alert Level",
    'STR_CONF_SNMP_GETVAL': "There was a problem while getting SNMP configuration.",
    'STR_CONF_SNMP_SETVAL': "There was a problem while setting SNMP configuration.",
    'STR_CONF_SNMP_CONFIRM': "Are you sure you want to Configure SNMP?",
    'STR_CONF_SNMP_SAVE_SUCCESS': "SNMP Alert configuration has been modified successfully.",

    # network
    'STR_CONF_NW_GETVAL': "There was a problem while getting Network configuration",
    'STR_CONF_NW_SETVAL': "There was a problem while setting Network configuration.\n",
    'STR_CONF_NW_GETERR1': "Could not get network settings",
    'STR_CONF_NW_SETERR1': "Unable to set the supplied network parameters ",
    'STR_CONF_NW_SAVE_CONFIRM': "This function may change the IP address of the device, and you may lose connectivity in this browser session.\nPlease reconnect using a new browser session after applying the changes.\nDo you want to proceed?",
    'STR_CONF_NW_RESET_TITLE': "Network configuration has been reset",
    'STR_CONF_NW_RESET_DESC': "Network configuration has been set successfully. It will take few seconds to bring up the interface again. Please close this browser session and open a new browser session to connect to the device with new IP. ",
    'STR_CONF_NW_ERR_222': "Either IP Address or Default Gateway IP is out of range.",
    'STR_CONF_NW_ERR_223': "Invalid IPv4 IP Address",
    'STR_CONF_NW_ERR_224': "Invalid IPv4 Default Gateway",
    'STR_CONF_NW_ERR_225': "Invalid IPv4 Subnet mask",
    'STR_CONF_NW_ERR_226': "Invalid IPv6 IP Address",
    'STR_CONF_NW_ERR_227': "Invalid IPv6 Default Gateway",
    'STR_CONF_NW_ERR_387': "Network interface cannot be disabled, as only one interface is currently enabled.",
    'STR_CONF_NW_ERR_469': "VLAN ID cannot be changed directly. To change the VLAN ID, disable the already enabled VLAN configuration, then try enabling the VLAN configuration with the new VLAN ID.",
    'strETH0': "eth0",
    'strETH1': "eth1",
    'strBOND0': "bond0",

    # /*General Strings*/
    'STR_PERMISSION_DENIED': "Permission denied to view this content.",
    'STR_CONF_ADMIN_PRIV': "You need to have administrator privileges to perform this action.",
    'STR_TIME_OUT': "The BMC seems to be taking too long to respond. Please check the cables and configuration",
    'STR_NOT_CONFIGURE': "Not Configured",
    'STR_NOT_AVAILABLE': "Not Available",
    'STR_DATA': "Data ",
    'STR_NOT_APPLICABLE': "N/A",
    'STR_NOT_SUPPORT': "Not Supported",
    'STR_NONE': "None",
    'STR_MANUAL': "Manual",
    'STR_AUTO': "Automatic",
    'STR_BLANK': "&nbsp,",			# Empty string
    'STR_EMPTY': " ",			# Empty string
    'STR_NEWLINE': "\n",
    'STR_HELP': "HELP",
    'STR_AND_ABOVE': " and Above",
    'STR_ANY': "Any",
    'STR_PROCESS_ABORT': "Ongoing process will be aborted.",
    'STR_FWFLASH_ABORT': "Closing the web session during firmware flash causes device to be restarted.",
    'STR_LOGOUT_SUCCESS': "You have been logged out successfully.",
    'STR_EVENT_ENTRIES': " Event entries",
    'STR_SAVE': "Save",
    'STR_ADD': "Add",
    'STR_MODIFY': "Modify",
    'STR_REPLACE': "Replace",
    'STR_CANCEL': "Cancel",
    'STR_ENABLED': "Enabled",
    'STR_DISABLED': "Disabled",
    'STR_HASH': "#",
    'STR_USERNAME': "Username",
    'STR_PASSWORD': "Password",
    'STR_DOMAINNAME': "Domain Name",
    'STR_SERVER_ADDRESS': "Server Address",
    'STR_SOURCE_PATH': "Source Path",
    'STR_RETRY_COUNT': "Retry Count",
    'STR_PRESERVE': "Preserve",
    'STR_OVERWRITE': "Overwrite",
    'STR_INACTIVE': "Inactive ",
    'STR_ACTIVE': "Active",
    'STR_STAND_BY': "Stand-by",
    'STR_YES': "Yes",
    'STR_NO': "No",
    'STR_NORMAL': 'Normal',
    'STR_WARNING': "Warning",
    'STR_ABNORMAL': "Abnormal",
    'STR_START': "Start",
    'STR_STOP': "Stop",

    # /*General Error Strings*/
    'STR_IPMI_ERROR': "  IPMI ERROR:",
    'STR_ERROR_CODE': "  Error Code : ",
    'STR_HELP_INFO': " Refer \'Help\' for more Information.",
    'STR_INVALID_FIELDS': "Following are the Invalid field(s),\n",
    'STR_INVALID_PORT': "Invalid Port Number",
    'STR_INVALID_IP': "Invalid IP Address format.",
    'STR_INVALID_TIMEOUT': "Invalid Time Out.",
    'STR_INVALID_SERVERADDR': "Invalid Server Address.",
    'STR_INVALID_USERNAME': "Invalid Username.",
    'STR_INVALID_PASSWORD': "Invalid Password.",
    'STR_INVALID_CPWORD': "Password and confirmation password do not match",
    'STR_INVALID_UNAME_PWORD': "Username/Password cannot be blank",
    'STR_INVALID_EMAILADDR': "Invalid Email Address.",
    'STR_INVALID_DOMAIN': "Invalid Domain Name.",
    'STR_INVALID_SEARCHBASE': "Invalid Search base.",
    'STR_INVALID_RGNAME': "Invalid Role Group Name.",
    'STR_INVALID_PAGENO': "Invalid Page Number.",
    'STR_INVALID_SRC_PATH': "Invalid Source Path.",
    'STR_NETWORK_ERROR': "There is some problem in network connection.",
    'STR_LANG_NOT_FOUND': "Browser language could not be determined. Using English(US) by default.",


    # /*General - Confirmation messages*/
    'STR_CONFIRM_DELETE': "Click OK if you want to continue deleting this entry.",
    'STR_GENERAL_COMMAND_CONFIRM': "Are you sure to execute this command？",
    'STR_GENERAL_LOGOUT': "Click OK if you want to continue logging out.",
    'STR_GENERAL_DISCONNECT': "Are you sure to disconnect from this server",
    'STR_CONSOLE_CONNECTED': "If exist, the Active Console Window will be closed.",
    'STR_SSLCERT_ABORT': "SSL certificate upload will be aborted.",
    'STR_IPMI_LIBRARY_ERROR': "IPMI library not responding. Please check if the IPMI process is running.",

    'STR_DEVICE_RESET_TITLE': "Device has been reset",
    'STR_DEVICE_RESET_DESC': "The device has been reset. Please close this browser session and open a new browser session to reconnect to the device. The device may take about a minute to boot up.",
    'STR_DEVICE_PREPARE_FAILED_RESET_DESC': "Fail to enter update mode ，the device has been reset. Please close this browser session and open a new browser session to reconnect to the device. The device may take about a minute to boot up.",
    'STR_UTC_OFFSET': "UTC Offset",
    'STR_GMT': "(GMT",

    # /*Firmware Update*/
    'STR_FW_UPDATE_CONFIRM1': "You will not be able to perform any other tasks until firmware upgrade is complete and the device is rebooted. Click Ok if you want to enter the update mode?",
    'STR_FW_UPDATE_CONFIRM2': "Are you sure to abort the firmware upgrade process? The device will have to be reset in order to go back to normal operating mode",
    'STR_FW_UPDATE_CONFIRM3': "New firmware image size is different from the existing firmware image size. \'Configuration\' can not be preserved in this situation. Do you want to continue?",
    'STR_FW_UPDATE_CONFIRM4': "Clicking \'OK\' will start the actual upgrade operation, where the storage is written with the new firmware image. It is essential that the upgrade operation is not interrupted once it starts. Do you wish to proceed?",
    'STR_FW_UPDATE_CONFIRM5': "Error in overwriting the files, Clicking \'OK\' will start the actual upgrade operation without overwrite the files, where the storage is written with the new firmware image. It is essential that the upgrade operation is not interrupted once it starts. Do you wish to proceed?",
    'STR_FW_UPDATE_ERR1': "Please enter a valid image file",
    'STR_FW_UPDATE_ERR2': "Image Verification unsuccessful. Please check if you uploaded the correct Image.",
    'STR_FW_UPDATE_ERR3': "Image Flashing unsuccessful.",
    'STR_FW_UPDATE_ERR4': "Image Verification unsuccessful. Please check if you uploaded the correct SignImage Public Key.",
    'STR_FW_UPDATE_ERR5': "Image Verification unsuccessful. The image uploaded is for different platform. Please check if you uploaded the correct Image.",

    'STR_FW_UPDATE_RESET_CONFIRM': "Press Cancle to reset the device now. Press OK to reload image.",
    'STR_FW_UPDATE_RESET': " In order to try upgrading again you need to reset the device. Press OK to reset the device now.",
    'STR_FW_FLASH_PROGRESS': "Flash is in Progress! Please try later",
    'STR_FW_VERIFY_DIFFVERSION': "The firmware image has been verified. The uploaded image is a different version of the existing device firmware.",
    'STR_FW_VERIFY_DIFFSIZE': "The firmware image has been verified. The uploaded image size is different from the existing device firmware.",
    'STR_FW_VERIFY_SAME': "The firmware image has been verified. The uploaded image appears to be the same as the existing device firmware.",
    'STR_FW_PREPARE_FLASH': "There was a problem while preparing device for firmware upgrade.",
    'STR_FW_DWLDIMG_ERR': "There was a problem while downloading firmware image from remote server. Please check if you have given the correct \'Firmware Image Transfer Protocol\' configuration.",
    'STR_FW_DWLDSTATUS_ERR': "There was a problem while getting download status of firmware image. Please check if you have given the correct \'Firmware Image Transfer Protocol\' configuration.",

    'STR_FW_SIGNKEY_GETVAL': "There was a problem while getting SignImage public key information.",
    'STR_FW_SIGNKEY_TITLE': "Upload  SignImage Public Key",
    'STR_FW_SIGNKEY_INFO': "Uploaded  SignImage Public Key",
    'STR_FW_NEW_SIGN_KEY': "New SignImage Public Key",
    'STR_FW_SIGNKEY_INVALID1': "Please enter a SignImage Public key file",
    'STR_FW_SIGNKEY_INVALID2': "SignImage Public key file name should end with .pem",
    'STR_FW_SIGNKEY_SUCCESS': "SignImage Public Key uploaded successfully",
    'STR_FW_SIGNKEY_ERR1': "The SignImage Public Key file does not exists",
    'STR_FW_SIGNKEY_ERR3': "The SignImage Public Key validation failed. Please try to upload the SignImage Public Key again.",
    'STR_FW_SIGNKEY_ERR4': "Uploading SignImage Public Key failed. Please try uploading the SignImage Public Key again.",
    'STR_FW_SIGNKEY_ERR5': "The SignImage Public Key file size exceeds",
    'STR_FW_SIGNKEY_VALIDATE_ERR': "There was a problem while validating SignImage Public Key",
    'STR_FW_PRSRV_CFG_DESC': " - irrespective of the individual items marked as preserve/overwrite in the table below.",

    'STR_FW_FLASH_IMAGE': "Flash Image",
    'STR_FW_BOOT_IMAGE': "Boot Image",
    'STR_FW_REBOOT_BMC': "Reboot BMC after Firmware flash",

    'STR_APP_STR_ALL_DEASSERTED': "All deasserted",
    'LAN_INTERFACE_NAME_BY_INDEX': ["Shared", "Dedicated", "bond0"],


    'refresh': "Refresh",
    'save': "Save",
    'reset': "Reset",
    'enable': "Enable",
    'cancel': "Cancel",

    'inactive': "Inactive",
    'active': "Active",
    'notApplicable': "N/A",
    'modify': "Modify",
    'add': "Add",
    'srvactive': "Active",
    'STR_EXPORT_LOG': "Export Log",
    'STR_CLEAR_LOG': "Clear Log",
    'STR_IMG_INFO': "Information",
    'STR_IMG_ON': "Power On/Present/Redundant",
    'STR_IMG_ON_1': "Present",
    'STR_IMG_ON_2': "Linkup",
    'STR_IMG_ON_3': "Present/Linkup",
    'STR_IMG_CRITICAL': "Critical",
    'STR_IMG_ABSENT': "Power Off/Absent/NA/No-Redundant",
    'STR_IMG_ABSENT_1': "Absent",
    'STR_IMG_ABSENT_2': "N/A",
    'STR_IMG_ABSENT_3': "Absent/Linkdown",
    'STR_IMG_WARNING': "Warning",
    'STR_IMG_OK': "Normal",
    'STR_IMG_OK_1': "Normal/Location/Rebuild",
    'STR_IMG_UNSPORRT': "Not Support",
    'STR_NOTE': "Note:",
    'STR_ATTRIBUTE': "Attribute",
    'STR_VALUE': "Value",
    'confirmAction': "Confirm to perform this action?",
    'confirmActionOK': "Succeed to perform the action!",
    'confirmActionFAIL': "Failed to perform the action!",
    'STR_BIOS_IO_TITLE': "BIOS Settins",
    'STR_BIOS_IO_EX': "Export The Settings File",
    'STR_BIOS_IO_UP': "Upload The Settings File",
    'STR_BIOS_IO_File': 'Select the file',
    'STR_BIOS_IO_UP_SU': "The file has been successfully uploaded",
    'STR_BIOS_IO_UP_FI': "The performance was failed",
    'preserveCFG': [
                {'name': "SDR", 'value': "sdr"},
                # {name:"FRU",value:"fru"},
                {'name': "SEL", 'value': "sel"},
                {'name': "IPMI", 'value': "ipmi"},
                {'name': "PEF", 'value': "pef"},
                {'name': "SOL", 'value': "sol"},
                {'name': "SMTP", 'value': "smtp"},
                {'name': "User", 'value': "user"},
                {'name': "DCMI", 'value': "dcmi"},
                {'name': "Network", 'value': "network"},
                {'name': "NTP", 'value': "ntp"},
                {'name': "SNMP", 'value': "snmp"},
                {'name': "SSH", 'value': "ssh"},
                {'name': "KVM", 'value': "kvm"},
                {'name': "Authentication", 'value': "authentication"},
                {'name': "Syslog", 'value': "syslog"},
                {'name': "Hostname", 'value': "hostname"}

    ],
    'videoTableHeader': [
        'ID',
        'Time Stamp',
        'Name'
    ],
    'STR_CLEAR_VIDEO_EMPTY': "No Video Log available, no need to clear!",
    'clearNote': "Are you sure to clear Log?",
    'clearSuccess': "Succeed to clear log",
    'clearFail': "Fail to clear log!",
    'wrongStr': "input is illegal or null"

}
commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_LAN_CH"] = {}
commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_LAN_CH"][0] = commonInfoStr["en"]["STR_MANUAL"]
commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_LAN_CH"][1] = commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_INDEX"][1]
commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_LAN_CH"][8] = commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_INDEX"][0]
# chenqiuyi_20160119 for lan channel change ++<<
commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_LAN_CH"]["eth1"] = commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_INDEX"][1]
commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_LAN_CH"]["eth0"] = commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_INDEX"][0]
commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_LAN_CH"]["bond0"] = commonInfoStr["en"]["LAN_INTERFACE_NAME_BY_INDEX"][2]

# chenqiuyi_20160119 for lan channel change ++>>
